pub unsafe extern "C" fn clhash(
random: *const c_void,
stringbyte: *const c_char,
lengthbyte: size_t,
) -> u64Expand description
random : the random data source (should contain at least RANDOM_BYTES_NEEDED_FOR_CLHASH random bytes), it should also be aligned on 16-byte boundaries so that (((uintptr_t) random & 15) == 0) for performance reasons. This is usually generated once and reused with many inputs.
stringbyte : the input data source, could be anything you want to has
length : number of bytes in the string